pub fn canonical_block_transaction(tx: FoundryTxEnvelope) -> FoundryTxEnvelopeExpand description
Drops pooled sidecars so a transaction uses its canonical block-body representation.
pub fn canonical_block_transaction(tx: FoundryTxEnvelope) -> FoundryTxEnvelopeDrops pooled sidecars so a transaction uses its canonical block-body representation.