create_block

Function create_block 

pub fn create_block<T, Tx>(
    header: Header,
    transactions: impl IntoIterator<Item = T>,
) -> Block<Tx>
where Tx: Encodable2718, T: Into<MaybeImpersonatedTransaction<Tx>>,
Helper function to create a new block with Header and Anvil transactions, generic over the transaction envelope with a default of [FoundryTxEnvelope].

Note: if the impersonate-tx feature is enabled this will also accept MaybeImpersonatedTransaction.